ExecutionCapabilities

Struct ExecutionCapabilities 

pub struct ExecutionCapabilities(/* private fields */);
OpenCL device execution capabilities

Implementations

Source

impl ExecutionCapabilities

pub const EXEC_KERNEL: ExecutionCapabilities

The device can execute OpenCL kernels

pub const EXEC_NATIVE_KERNEL: ExecutionCapabilities

The device can execute native host kernels

pub const unsafe fn new(value: cl_device_exec_capabilities) -> Self

Create a new wrapped bitfield from the given raw bitfield value.

Safety

This function can be used to create bitfields representing non-existent flags. You must ensure that the resulting bitfield is legal anywhere it’s used.

pub const fn raw(self) -> cl_device_exec_capabilities

Unwrap this bitfield into the underlying value

pub const fn contains(self, other: Self) -> bool

Check whether this bitfield is equal to or a superset of a given bitfield