FPConfig

Struct FPConfig 

pub struct FPConfig(/* private fields */);
A bitfield representing floating point mode support

Implementations

Source

impl FPConfig

pub const DENORM: FPConfig

pub const INF_NAN: FPConfig

pub const ROUND_TO_NEAREST: FPConfig

pub const ROUND_TO_ZERO: FPConfig

pub const ROUND_TO_INF: FPConfig

pub const FMA: FPConfig

pub const CORRECTLY_ROUNDED_DIVIDE_SQRT: FPConfig

pub const SOFT_FLOAT: FPConfig

pub const unsafe fn new(value: cl_device_fp_config) -> Self

Create a new wrapped bitfield from the given raw bitfield value.

Safety

This function can be used to create bitfields representing non-existent flags. You must ensure that the resulting bitfield is legal anywhere it’s used.

pub const fn raw(self) -> cl_device_fp_config

Unwrap this bitfield into the underlying value

pub const fn contains(self, other: Self) -> bool

Check whether this bitfield is equal to or a superset of a given bitfield