SVMCapabilities

Struct SVMCapabilities 

pub struct SVMCapabilities(/* private fields */);
OpenCL device SVM capabilities

Implementations

Source

impl SVMCapabilities

pub const COARSE_GRAIN_BUFFER: SVMCapabilities

pub const FINE_GRAIN_BUFFER: SVMCapabilities

pub const FINE_GRAIN_SYSTEM: SVMCapabilities

pub const ATOMICS: SVMCapabilities

pub const unsafe fn new(value: cl_device_svm_capabilities) -> Self

Create a new wrapped bitfield from the given raw bitfield value.

Safety

This function can be used to create bitfields representing non-existent flags. You must ensure that the resulting bitfield is legal anywhere it’s used.

pub const fn raw(self) -> cl_device_svm_capabilities

Unwrap this bitfield into the underlying value

pub const fn contains(self, other: Self) -> bool

Check whether this bitfield is equal to or a superset of a given bitfield