pub trait BindProject<'a>: BindProjectInternal<'a> {
type Projected: 'a;
}Expand description
A helper trait allowing a pinned reference to a bound kernel argument list to be projected such that each argument is individually pinned, allowing destructuring and individual use.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.