QueueProperties

Struct QueueProperties 

pub struct QueueProperties(/* private fields */);
Special command queue properties

Implementations

Source

impl QueueProperties

pub const OUT_OF_ORDER_EXEC_MODE_ENABLE: QueueProperties

pub const PROFILING_ENABLE: QueueProperties

pub const ON_DEVICE: QueueProperties

pub const ON_DEVICE_DEFAULT: QueueProperties

pub const unsafe fn new(value: cl_command_queue_properties) -> Self

Create a new wrapped bitfield from the given raw bitfield value.

Safety

This function can be used to create bitfields representing non-existent flags. You must ensure that the resulting bitfield is legal anywhere it’s used.

pub const fn raw(self) -> cl_command_queue_properties

Unwrap this bitfield into the underlying value

pub const fn contains(self, other: Self) -> bool

Check whether this bitfield is equal to or a superset of a given bitfield