pub struct FPConfig(/* private fields */);Expand description
A bitfield representing floating point mode support
Implementations
Sourceimpl FPConfig
impl FPConfig
pub const DENORM: FPConfig
pub const INF_NAN: FPConfig
pub const ROUND_TO_NEAREST: FPConfig
pub const ROUND_TO_ZERO: FPConfig
pub const ROUND_TO_INF: FPConfig
pub const FMA: FPConfig
pub const CORRECTLY_ROUNDED_DIVIDE_SQRT: FPConfig
pub const SOFT_FLOAT: FPConfig
Sourcepub const unsafe fn new(value: cl_device_fp_config) -> Self
pub const unsafe fn new(value: cl_device_fp_config) -> Self
Create a new wrapped bitfield from the given raw bitfield value.
Safety
This function can be used to create bitfields representing non-existent flags. You must ensure that the resulting bitfield is legal anywhere it’s used.
Sourcepub const fn raw(self) -> cl_device_fp_config
pub const fn raw(self) -> cl_device_fp_config
Unwrap this bitfield into the underlying value